@@ -1,5 +1,5 @@
 package Bot::Cobalt::Common;
-$Bot::Cobalt::Common::VERSION = '0.017006';
+$Bot::Cobalt::Common::VERSION = '0.017007';
 use v5.10;
 use strictures 2;
 use Carp;
@@ -11,6 +11,7 @@ use Import::Into;
 use Bot::Cobalt::Utils ();
 use IRC::Utils ();
 use Object::Pluggable::Constants ();
+use Try::Tiny ();
 
 use Types::Standard ();
 use List::Objects::Types ();
@@ -78,21 +79,21 @@ our $ImportMap = hash(
 
 my $FuncMap = 
   $ImportMap
-  ->values
-  ->map(sub {
-      my @func_pkg_pairs;
-      my $iter = $_->iter;
-      while (my ($pkg, $opts) = $iter->()) {
-        $opts->visit(sub {
-          my $maybe_prefix = substr $_, 0, 1;
-          push @func_pkg_pairs, ($_ => $pkg)
-            unless $maybe_prefix eq ':'
-            or     $maybe_prefix eq '-'
-        })
-      }
-      @func_pkg_pairs
-    })
-  ->inflate;
+    ->values
+    ->map(sub {
+        my @func_pkg_pairs;
+        my $iter = $_->iter;
+        while (my ($pkg, $opts) = $iter->()) {
+          $opts->visit(sub {
+            my $maybe_prefix = substr $_, 0, 1;
+            push @func_pkg_pairs, ($_ => $pkg)
+              unless $maybe_prefix eq ':'
+              or     $maybe_prefix eq '-'
+          })
+        }
+        @func_pkg_pairs
+      })
+    ->inflate;
 
 sub import {
   my (undef, @items) = @_;
@@ -100,6 +101,7 @@ sub import {
 
   feature->import( ':5.10' );
   strictures->import::into($target);
+  Try::Tiny->import::into($target);
 
   my $toimport = hash;
 
@@ -185,6 +187,8 @@ used tools and constants to make life easier on plugin authors.
 L<strictures> are also enabled. This will turn on 'strict' and make (most)
 warnings fatal.
 
+L<Try::Tiny> is always imported.
+
 =head2 Exported
 
 =head3 Constants
