@@ -1,5 +1,5 @@
 package Bot::Cobalt::Conf::Role::Reader;
-$Bot::Cobalt::Conf::Role::Reader::VERSION = '0.017006';
+$Bot::Cobalt::Conf::Role::Reader::VERSION = '0.017007';
 use Carp;
 use strictures 2;
 
@@ -10,7 +10,7 @@ use Bot::Cobalt::Serializer;
 
 use Moo::Role;
 
-has '_serializer' => (
+has _serializer => (
   is        => 'ro',
   isa       => InstanceOf['Bot::Cobalt::Serializer'],
   builder   => sub { Bot::Cobalt::Serializer->new },
@@ -26,9 +26,9 @@ sub readfile {
   my $thawed_cf = try {
     $self->_serializer->readfile( $path )
   } catch {
-    $err = $_;
-    ()
+    $err = $_
   };
+
   confess "Serializer readfile() failed for $path; $err"
     if defined $err;
 
