@@ -1,21 +1,17 @@
 package Bot::Cobalt::Core::ContextMeta::Auth;
-$Bot::Cobalt::Core::ContextMeta::Auth::VERSION = '0.017006';
-
-use v5.10;
+$Bot::Cobalt::Core::ContextMeta::Auth::VERSION = '0.017007';
 use strictures 2;
-
 use Carp;
 
-use Bot::Cobalt::Common qw/:types/;
+use Bot::Cobalt::Common ':types';
 
 
 use Moo;
 extends 'Bot::Cobalt::Core::ContextMeta';
 
-around 'add' => sub {
-  my $orig = shift;
-  my $self = shift;
-  
+
+around add => sub {
+  my ($orig, $self) = splice @_, 0, 2;
   ## auth->add(
   ##   Context  => $context,
   ##   Username => $username,
@@ -24,7 +20,6 @@ around 'add' => sub {
   ##   Flags    => $flags,
   ##   Alias    => $plugin_alias
   ## )
-
   my %args = @_;
   $args{lc $_} = delete $args{$_} for keys %args;
   
@@ -46,46 +41,56 @@ around 'add' => sub {
     Flags => $args{flags},
   };
 
-  $self->$orig($args{context}, $args{nickname}, $meta);
+  $self->$orig($args{context}, $args{nickname}, $meta)
 };
 
 sub level {
   my ($self, $context, $nickname) = @_;
 
-  return 0 unless defined $context and defined $nickname;
-  
-  return 0 unless exists $self->_list->{$context}
-         and ref $self->_list->{$context}->{$nickname};
+  return 0
+    unless defined $context
+    and defined $nickname
+    and exists $self->_list->{$context}
+    and ref $self->_list->{$context}->{$nickname};
   
   $self->_list->{$context}->{$nickname}->{Level} // 0
 }
 
 sub set_flag {
   my ($self, $context, $nickname, $flag) = @_;
-  return unless defined $context and defined $nickname and $flag;  
-  
-  return unless exists $self->_list->{$context} 
-         and exists $self->_list->{$context}->{$nickname};
+
+  return
+    unless defined $context
+    and defined $nickname
+    and $flag
+    and exists $self->_list->{$context} 
+    and exists $self->_list->{$context}->{$nickname};
   
   $self->_list->{$context}->{$nickname}->{Flags}->{$flag} = 1
 }
 
 sub drop_flag {
   my ($self, $context, $nickname, $flag) = @_;
-  return unless defined $context and defined $nickname and $flag;  
-  
-  return unless exists $self->_list->{$context} 
-         and exists $self->_list->{$context}->{$nickname};
+
+  return
+    unless defined $context 
+    and defined $nickname 
+    and $flag
+    and exists $self->_list->{$context} 
+    and exists $self->_list->{$context}->{$nickname};
 
   delete $self->_list->{$context}->{$nickname}->{Flags}->{$flag}
 }
 
 sub has_flag {
   my ($self, $context, $nickname, $flag) = @_;
-  return unless defined $context and defined $nickname and $flag;  
-  
-  return unless exists $self->_list->{$context} 
-         and exists $self->_list->{$context}->{$nickname};
+
+  return
+    unless defined $context 
+    and defined $nickname 
+    and $flag
+    and exists $self->_list->{$context} 
+    and exists $self->_list->{$context}->{$nickname};
 
   $self->_list->{$context}->{$nickname}->{Flags}->{$flag}
 }
@@ -95,19 +100,21 @@ sub flags {
 
   return +{} unless exists $self->_list->{$context}
          and ref $self->_list->{$context}->{$nickname}
-         and ref $self->_list->{$context}->{$nickname}->{Flags} eq 'HASH';
+         and ref $self->_list->{$context}->{$nickname}->{Flags}
+         and reftype $self->_list->{$context}->{$nickname}->{Flags} eq 'HASH';
 
   $self->_list->{$context}->{$nickname}->{Flags}
 }
 
-sub user { goto &username }
+{ no warnings 'once'; *user = *username }
 sub username {
   my ($self, $context, $nickname) = @_;
   
-  return unless defined $context and defined $nickname;
-  
-  return unless exists $self->_list->{$context}
-         and ref $self->_list->{$context}->{$nickname};
+  return
+    unless defined $context
+    and defined $nickname
+    and exists $self->_list->{$context}
+    and ref $self->_list->{$context}->{$nickname};
 
   $self->_list->{$context}->{$nickname}->{Username}
 }
@@ -115,20 +122,23 @@ sub username {
 sub host {
   my ($self, $context, $nickname) = @_;
   
-  return unless defined $context and defined $nickname;
-  
-  return unless exists $self->_list->{$context}
-         and ref $self->_list->{$context}->{$nickname};
+  return
+    unless defined $context 
+    and defined $nickname
+    and exists $self->_list->{$context}
+    and ref $self->_list->{$context}->{$nickname};
 
   $self->_list->{$context}->{$nickname}->{Host}
 }
 
 sub alias {
   my ($self, $context, $nickname) = @_;
-  return unless defined $context and defined $nickname;
-  
-  return unless exists $self->_list->{$context}
-         and ref $self->_list->{$context}->{$nickname};
+
+  return
+    unless defined $context 
+    and defined $nickname
+    and exists $self->_list->{$context}
+    and ref $self->_list->{$context}->{$nickname};
 
   $self->_list->{$context}->{$nickname}->{Alias}
 }
@@ -139,8 +149,8 @@ sub move {
   
   return unless exists $self->_list->{$context}->{$old};
   
-  $self->_list->{$context}->{$new} =  
-    delete $self->_list->{$context}->{$old}
+  $self->_list->{$context}->{$new}
+    = delete $self->_list->{$context}->{$old}
 }
 
 
