@@ -1,15 +1,11 @@
 package Bot::Cobalt::Core::Loader;
-$Bot::Cobalt::Core::Loader::VERSION = '0.017006';
-use v5.10;
+$Bot::Cobalt::Core::Loader::VERSION = '0.017007';
 use strictures 2;
-
 use Carp;
-
-use Scalar::Util qw/blessed/;
+use Scalar::Util 'blessed';
 
 use Try::Tiny;
 
-
 sub new { bless [], shift }
 
 sub is_reloadable {
