@@ -1,8 +1,8 @@
 package Bot::Cobalt::Core::Role::EasyAccessors;
-$Bot::Cobalt::Core::Role::EasyAccessors::VERSION = '0.017006';
+$Bot::Cobalt::Core::Role::EasyAccessors::VERSION = '0.017007';
 use strictures 2;
 
-use Scalar::Util qw/blessed/;
+use Scalar::Util 'blessed', 'reftype';
 use Carp;
 
 use Moo::Role;
@@ -24,7 +24,9 @@ sub get_channels_cfg {
   
   for my $channel (keys %$chcfg) {
     ## Might be an empty string:
-    $chcfg->{$channel} = {} unless ref $chcfg->{$channel} eq 'HASH';
+    $chcfg->{$channel} = +{}
+      unless ref $chcfg->{$channel}
+      and reftype $chcfg->{$channel} eq 'HASH'
   }
   
   $chcfg
