@@ -1,5 +1,5 @@
 package Bot::Cobalt::Core::Role::Timers;
-$Bot::Cobalt::Core::Role::Timers::VERSION = '0.017006';
+$Bot::Cobalt::Core::Role::Timers::VERSION = '0.017007';
 use 5.10.1;
 use strictures 2;
 
@@ -68,10 +68,9 @@ sub timer_set_hashref {
   my $d_line = "$caller_pkg line $caller_line";
   
   unless (ref $ev eq 'HASH') {
-  
     if (ref $ev) {
       $self->log->warn(
-        "timer_set_hashref not called with hashref; $d_line"
+        "timer_set_hashref expected HASH but got $ev; $d_line"
       );
       return
     } else {
