@@ -1,5 +1,5 @@
 package Bot::Cobalt::DB;
-$Bot::Cobalt::DB::VERSION = '0.017006';
+$Bot::Cobalt::DB::VERSION = '0.017007';
 ## Uses proper retie-after-lock technique for locking
 
 use v5.10;
@@ -285,9 +285,7 @@ sub get {
   confess "attempted 'get' on unopened db"
     unless $self->is_open;
 
-  return unless exists $self->Tied->{$key};
-
-  $self->tied->{$key}
+  exists $self->Tied->{$key} ? $self->tied->{$key} : ()
 }
 
 sub put {
