@@ -1,5 +1,5 @@
 package Bot::Cobalt::Lang;
-$Bot::Cobalt::Lang::VERSION = '0.017006';
+$Bot::Cobalt::Lang::VERSION = '0.017007';
 use v5.10;
 use strictures 2;
 use Carp;
@@ -113,8 +113,8 @@ has rpls => (
       ## croak() by default.
       ## If this is a core set load, return empty hash.
       if ( !$self->use_core ) {
-        $croakable = "readfile() failure for ". $self->lang().
-          "(". $self->_full_lang_path(). "): ".
+        $croakable = "readfile() failure for " . $self->lang .
+          "(" . $self->_full_lang_path . "): " .
           $_ ;
         undef
       } else {
