@@ -1,5 +1,5 @@
 package Bot::Cobalt::Logger;
-$Bot::Cobalt::Logger::VERSION = '0.017006';
+$Bot::Cobalt::Logger::VERSION = '0.017007';
 use strictures 2;
 use Carp;
 
@@ -88,13 +88,11 @@ sub _should_log {
 sub _log_to_level {
   my ($self, $level) = splice @_, 0, 2;
 
-  return 1 unless $self->_should_log($level);
-
   $self->output->_write(
     $level,
     [ caller(1) ],
     @_
-  );
+  ) if $self->_should_log($level);
 
   1
 }
