@@ -1,12 +1,8 @@
 package Bot::Cobalt::Plugin::Extras::Karma;
-$Bot::Cobalt::Plugin::Extras::Karma::VERSION = '0.017006';
-
-
+$Bot::Cobalt::Plugin::Extras::Karma::VERSION = '0.017007';
 ## simple karma++/-- tracking
 
-use 5.10.1;
-use strict;
-use warnings;
+use strictures 2;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
