@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Info3;
-$Bot::Cobalt::Plugin::Info3::VERSION = '0.017006';
+$Bot::Cobalt::Plugin::Info3::VERSION = '0.017007';
 use strictures 2;
 use v5.10;
 
@@ -743,7 +743,6 @@ sub _info_exec_dsearch {
 
   for my $glob (keys %{ $self->{Globs} }) {
     my $ref = $self->{DB}->get($glob);
-
     unless (ref $ref eq 'HASH') {
       logger->error(
         "Inconsistent Info3? $glob appears to have no value.",
@@ -807,7 +806,7 @@ sub _info_varhelp {
   my ($self, $msg) = @_;
 
   my $help =
-     ' !~ = CmdChar, B~ = BotNick, C = Channel, H = UserHost, N = Nick,'
+     ' !~ = CmdChar, B~ = BotNick, C~ = Channel, H~ = UserHost, N~ = Nick,'
     .' P~ = Port, Q~ = Question, R~ = RandomNick, S~ = Server'
     .' t~ = unixtime, T~ = localtime, V~ = Version, W~ = Website'
   ;
