@@ -1,8 +1,5 @@
 package Bot::Cobalt::Plugin::Master;
-$Bot::Cobalt::Plugin::Master::VERSION = '0.017006';
-
-
-use 5.10.1;
+$Bot::Cobalt::Plugin::Master::VERSION = '0.017007';
 use strictures 2;
 
 use Bot::Cobalt;
@@ -43,8 +40,6 @@ sub Cobalt_unregister {
 }
 
 
-### JOIN / PART / CYCLE
-
 sub Bot_public_cmd_cycle {
   my ($self, $core) = splice @_, 0, 2;
   my $msg = ${ $_[0] };
