@@ -1,14 +1,14 @@
 package Bot::Cobalt::Plugin::RDB::AsyncSearch;
-$Bot::Cobalt::Plugin::RDB::AsyncSearch::VERSION = '0.017006';
-
-
-use 5.10.1;
+$Bot::Cobalt::Plugin::RDB::AsyncSearch::VERSION = '0.017007';
 use Carp;
 use strictures 2;
 
 use Config;
 
-use POE qw/Wheel::Run Filter::Reference/;
+use POE qw/
+  Wheel::Run
+  Filter::Reference
+/;
 
 sub new { bless [], shift }
 
