@@ -1,21 +1,19 @@
 package Bot::Cobalt::Serializer;
-$Bot::Cobalt::Serializer::VERSION = '0.017006';
-use v5.10;
+$Bot::Cobalt::Serializer::VERSION = '0.017007';
 use strictures 2;
 use Carp;
+use Scalar::Util 'reftype';
 
 ## These two must be present anyway:
 use YAML::XS ();
 use JSON::MaybeXS ();
 
-use Fcntl qw/:flock/;
-
-use Bot::Cobalt::Common qw/:types/;
-
-use Time::HiRes qw/sleep/;
-
+use Fcntl ':flock';
+use Time::HiRes  'sleep';
 use Scalar::Util 'blessed';
 
+use Bot::Cobalt::Common ':types';
+
 use Moo;
 
 
@@ -197,7 +195,7 @@ sub _read_serialized {
   return unless defined $path;
 
   my $lock = 1;
-  if (defined $opts && ref $opts eq 'HASH') {
+  if (defined $opts && ref $opts && reftype $opts eq 'HASH') {
     $lock = $opts->{Locking} if defined $opts->{Locking};
   }
 
@@ -230,7 +228,7 @@ sub _write_serialized {
   my $lock    = 1;
   my $timeout = 2;
 
-  if (defined $opts && ref $opts eq 'HASH') {
+  if (defined $opts && ref $opts && reftype $opts eq 'HASH') {
     $lock    = $opts->{Locking} if defined $opts->{Locking};
     $timeout = $opts->{Timeout} if $opts->{Timeout};
   }
